@@ -4,12 +4,15 @@
 #' @export
 #' @import utils
 #' @param x An object of class cusum
-#' @param signal If TRUE, signals are plotted (default)
+#' @param signal Logical. If TRUE, signals are plotted (default)
 #' @method plot cusum
 #' @usage ## S3 method for class 'cusum' plot(x, signal = TRUE, ...)
 
 
 plot.cusum <- function(x, signal = TRUE, ...) {
+  
+  assert_logical(signal, len = 1)
+
   if (mean(x$ct) < 0){
     y_lim <- c(min(x$ct), 0)
   } else {
@@ -27,13 +30,15 @@ plot.cusum <- function(x, signal = TRUE, ...) {
   )
 
   if (signal == TRUE) {
+    #p_signal <- which(x$signal == 1)  - 1
+    p_signal <- which(x$signal == 1)
     points(
-      x = x$t[x$signal == 1],
-      y = x$ct[x$signal == 1],
-      col = "red",
-      cex = 2,
+      x = x$t[p_signal],
+      y = x$ct[p_signal],
+      col = "orange",
+      cex = 1.8,
       pch = 8,
-      lwd = 5
+      lwd = 2.5 
     )
   }
   
